@@ -4,12 +4,13 @@ from typing import List
 import pandas as pd
 import matplotlib.pyplot as plt
 
+from roxieapi.cadata.CableDefinition import CableDefinition
+from roxieapi.cadata.ConductorDefinition import ConductorDefinition
+from roxieapi.cadata.InsulationDefinition import InsulationDefinition
+from roxieapi.cadata.StrandDefinition import StrandDefinition
+
 from magnumapi.geometry.definitions.BlockDefinition import BlockDefinition
 from magnumapi.geometry.primitives.Area import Area
-from magnumapi.cadata.CableDefinition import CableDefinition
-from magnumapi.cadata.ConductorDefinition import ConductorDefinition
-from magnumapi.cadata.InsulationDefinition import InsulationDefinition
-from magnumapi.cadata.StrandDefinition import StrandDefinition
 
 
 class Block(ABC):
